==> members-facade-1.5.4-vg-0928-20220928.105024-7-sources.jar: com/bizvane/members/facade/service/vg/VGMemberApiService.java <==
package com.bizvane.members.facade.service.vg;

import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.vo.LevelRecordVo;
import com.bizvane.members.facade.vo.vg.*;
import com.bizvane.stagekafkaservice.models.po.SysStaffPo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.Valid;
import java.util.List;

@FeignClient(value = "${feign.client.members.name}", path = "${feign.client.members.path}")
public interface VGMemberApiService {


    @PostMapping(value = "/api/jinhong/openCard")
    ResponseData<VGMemberOpenCardResponseVo> openCard(@RequestBody @Valid VGMemberOpenCardRequestVo requestVo);

    @PostMapping(value = "/api/jinhong/memberQuery")
    ResponseData<VGMemberQueryResponseVo> memberQuery(@RequestBody @Valid VGMemberQueryRequestVo requestVo);

    @PostMapping(value = "/api/jinhong/changeMemberLevel")
    ResponseData changeMemberLevel(@RequestBody @Valid VGMemberLevelChangeVo vo);

    @PostMapping(value = "/api/jinhong/changeMemberPhone")
    ResponseData changeMemberPhone(@RequestBody @Valid VGMemberPhoneChangeVo vo);

    @PostMapping(value = "/api/jinhong/memberInitGuideQuery")
    ResponseData<MemberInitGuideQueryResponseVo> memberInitGuideQuery(@RequestBody @Valid MemberInitGuideQueryRequestVo requestVo);

    @PostMapping(value = "/api/jinhong/searchAllMembersByMemberCode")
    ResponseData<List<MemberInfoModel>> searchAllMembersByMemberCode(@RequestParam("memberCode") String memberCode);
}

==> members-facade-1.5.9-vg-1019-20230314.105515-1-sources.jar: com/bizvane/members/facade/service/vg/VGMemberApiService.java <==
package com.bizvane.members.facade.service.vg;

import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.vo.LevelRecordVo;
import com.bizvane.members.facade.vo.vg.*;
import com.bizvane.stagekafkaservice.models.po.SysStaffPo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.Valid;
import java.util.List;

@FeignClient(value = "${feign.client.members.name}", path = "${feign.client.members.path}")
public interface VGMemberApiService {


    @PostMapping(value = "/api/jinhong/openCard")
    ResponseData<VGMemberOpenCardResponseVo> openCard(@RequestBody @Valid VGMemberOpenCardRequestVo requestVo);

    @PostMapping(value = "/api/jinhong/memberQuery")
    ResponseData<VGMemberQueryResponseVo> memberQuery(@RequestBody @Valid VGMemberQueryRequestVo requestVo);

    @PostMapping(value = "/api/jinhong/changeMemberLevel")
    ResponseData changeMemberLevel(@RequestBody @Valid VGMemberLevelChangeVo vo);

    @PostMapping(value = "/api/jinhong/changeMemberPhone")
    ResponseData changeMemberPhone(@RequestBody @Valid VGMemberPhoneChangeVo vo);

    @PostMapping(value = "/api/jinhong/memberInitGuideQuery")
    ResponseData<MemberInitGuideQueryResponseVo> memberInitGuideQuery(@RequestBody @Valid MemberInitGuideQueryRequestVo requestVo);

    @PostMapping(value = "/api/jinhong/searchAllMembersByMemberCode")
    ResponseData<List<MemberInfoModel>> searchAllMembersByMemberCode(@RequestParam("memberCode") String memberCode);

    /**
     * 会员续会等级
     * @param vo
     * @return
     */
    @PostMapping(value = "/api/jinhong/keepMemberLevel")
    ResponseData keepMemberLevel(@RequestBody @Valid VGMemberLevelKeepVo vo);

}
